import { withTheme } from '@rjsf/core';
import { jsx, jsxs, Fragment } from 'react/jsx-runtime';
import { TranslatableString, getUiOptions, getTemplate, getInputProps, examplesId, ariaDescribedByIds, errorId, helpId, titleId, descriptionId, canExpand, getSubmitButtonOptions, ADDITIONAL_PROPERTY_FLAG, schemaRequiresTrueValue, labelValue, enumOptionsIsSelected, optionId, enumOptionsSelectValue, enumOptionsDeselectValue, enumOptionsValueForIndex, enumOptionsIndexForValue } from '@rjsf/utils';
import Button from 'react-bootstrap/Button';
import { BsPlus } from '@react-icons/all-files/bs/BsPlus';
import Row from 'react-bootstrap/Row';
import Col from 'react-bootstrap/Col';
import Container from 'react-bootstrap/Container';
import Form$1 from 'react-bootstrap/Form';
import Card from 'react-bootstrap/Card';
import ListGroup from 'react-bootstrap/ListGroup';
import { IoIosCopy } from '@react-icons/all-files/io/IoIosCopy';
import { IoIosRemove } from '@react-icons/all-files/io/IoIosRemove';
import { AiOutlineArrowUp } from '@react-icons/all-files/ai/AiOutlineArrowUp';
import { AiOutlineArrowDown } from '@react-icons/all-files/ai/AiOutlineArrowDown';
import FormControl from 'react-bootstrap/FormControl';
import InputGroup from 'react-bootstrap/InputGroup';

function AddButton({
  uiSchema,
  registry,
  ...props
}) {
  const {
    translateString
  } = registry;
  return jsx(Button, {
    ...props,
    style: {
      width: '100%'
    },
    className: `ml-1 ${props.className}`,
    title: translateString(TranslatableString.AddItemButton),
    children: jsx(BsPlus, {})
  });
}

function ArrayFieldItemTemplate(props) {
  const {
    children,
    disabled,
    hasToolbar,
    hasCopy,
    hasMoveDown,
    hasMoveUp,
    hasRemove,
    index,
    onCopyIndexClick,
    onDropIndexClick,
    onReorderClick,
    readonly,
    registry,
    uiSchema
  } = props;
  const {
    CopyButton,
    MoveDownButton,
    MoveUpButton,
    RemoveButton
  } = registry.templates.ButtonTemplates;
  const btnStyle = {
    flex: 1,
    paddingLeft: 6,
    paddingRight: 6,
    fontWeight: 'bold'
  };
  return jsx("div", {
    children: jsxs(Row, {
      className: 'mb-2  d-flex align-items-center',
      children: [jsx(Col, {
        xs: '9',
        lg: '9',
        children: children
      }), jsx(Col, {
        xs: '3',
        lg: '3',
        className: 'py-4',
        children: hasToolbar && jsxs("div", {
          className: 'd-flex flex-row',
          children: [(hasMoveUp || hasMoveDown) && jsx("div", {
            className: 'm-0 p-0',
            children: jsx(MoveUpButton, {
              className: 'array-item-move-up',
              style: btnStyle,
              disabled: disabled || readonly || !hasMoveUp,
              onClick: onReorderClick(index, index - 1),
              uiSchema: uiSchema,
              registry: registry
            })
          }), (hasMoveUp || hasMoveDown) && jsx("div", {
            className: 'm-0 p-0',
            children: jsx(MoveDownButton, {
              style: btnStyle,
              disabled: disabled || readonly || !hasMoveDown,
              onClick: onReorderClick(index, index + 1),
              uiSchema: uiSchema,
              registry: registry
            })
          }), hasCopy && jsx("div", {
            className: 'm-0 p-0',
            children: jsx(CopyButton, {
              style: btnStyle,
              disabled: disabled || readonly,
              onClick: onCopyIndexClick(index),
              uiSchema: uiSchema,
              registry: registry
            })
          }), hasRemove && jsx("div", {
            className: 'm-0 p-0',
            children: jsx(RemoveButton, {
              style: btnStyle,
              disabled: disabled || readonly,
              onClick: onDropIndexClick(index),
              uiSchema: uiSchema,
              registry: registry
            })
          })]
        })
      })]
    })
  });
}

function ArrayFieldTemplate(props) {
  const {
    canAdd,
    disabled,
    idSchema,
    uiSchema,
    items,
    onAddClick,
    readonly,
    registry,
    required,
    schema,
    title
  } = props;
  const uiOptions = getUiOptions(uiSchema);
  const ArrayFieldDescriptionTemplate = getTemplate('ArrayFieldDescriptionTemplate', registry, uiOptions);
  const ArrayFieldItemTemplate = getTemplate('ArrayFieldItemTemplate', registry, uiOptions);
  const ArrayFieldTitleTemplate = getTemplate('ArrayFieldTitleTemplate', registry, uiOptions);
  // Button templates are not overridden in the uiSchema
  const {
    ButtonTemplates: {
      AddButton
    }
  } = registry.templates;
  return jsx("div", {
    children: jsx(Row, {
      className: 'p-0 m-0',
      children: jsxs(Col, {
        className: 'p-0 m-0',
        children: [jsx(ArrayFieldTitleTemplate, {
          idSchema: idSchema,
          title: uiOptions.title || title,
          schema: schema,
          uiSchema: uiSchema,
          required: required,
          registry: registry
        }), jsx(ArrayFieldDescriptionTemplate, {
          idSchema: idSchema,
          description: uiOptions.description || schema.description,
          schema: schema,
          uiSchema: uiSchema,
          registry: registry
        }), jsxs(Container, {
          fluid: true,
          className: 'p-0 m-0',
          children: [items && items.map(({
            key,
            ...itemProps
          }) => jsx(ArrayFieldItemTemplate, {
            ...itemProps
          }, key)), canAdd && jsx(Container, {
            className: '',
            children: jsxs(Row, {
              className: 'mt-2',
              children: [jsx(Col, {
                xs: 9
              }), jsx(Col, {
                xs: 3,
                className: 'py-4 col-lg-3 col-3',
                children: jsx(AddButton, {
                  className: 'array-item-add',
                  onClick: onAddClick,
                  disabled: disabled || readonly,
                  uiSchema: uiSchema,
                  registry: registry
                })
              })]
            })
          })]
        }, `array-item-list-${idSchema.$id}`)]
      })
    })
  });
}

function BaseInputTemplate({
  id,
  placeholder,
  required,
  readonly,
  disabled,
  type,
  value,
  onChange,
  onChangeOverride,
  onBlur,
  onFocus,
  autofocus,
  options,
  schema,
  rawErrors = [],
  children,
  extraProps
}) {
  const inputProps = {
    ...extraProps,
    ...getInputProps(schema, type, options)
  };
  const _onChange = ({
    target: {
      value
    }
  }) => onChange(value === '' ? options.emptyValue : value);
  const _onBlur = ({
    target: {
      value
    }
  }) => onBlur(id, value);
  const _onFocus = ({
    target: {
      value
    }
  }) => onFocus(id, value);
  // const classNames = [rawErrors.length > 0 ? "is-invalid" : "", type === 'file' ? 'custom-file-label': ""]
  return jsxs(Fragment, {
    children: [jsx(Form$1.Control, {
      id: id,
      name: id,
      placeholder: placeholder,
      autoFocus: autofocus,
      required: required,
      disabled: disabled,
      readOnly: readonly,
      className: rawErrors.length > 0 ? 'is-invalid' : '',
      list: schema.examples ? examplesId(id) : undefined,
      ...inputProps,
      value: value || value === 0 ? value : '',
      onChange: onChangeOverride || _onChange,
      onBlur: _onBlur,
      onFocus: _onFocus,
      "aria-describedby": ariaDescribedByIds(id, !!schema.examples)
    }), children, Array.isArray(schema.examples) ? jsx("datalist", {
      id: examplesId(id),
      children: schema.examples.concat(schema.default && !schema.examples.includes(schema.default) ? [schema.default] : []).map(example => {
        return jsx("option", {
          value: example
        }, example);
      })
    }) : null]
  });
}

function DescriptionField({
  id,
  description
}) {
  if (description) {
    return jsx("div", {
      children: jsx("div", {
        id: id,
        className: 'mb-3',
        children: description
      })
    });
  }
  return null;
}

function ErrorList({
  errors,
  registry
}) {
  const {
    translateString
  } = registry;
  return jsxs(Card, {
    border: 'danger',
    className: 'mb-4',
    children: [jsx(Card.Header, {
      className: 'alert-danger',
      children: translateString(TranslatableString.ErrorsLabel)
    }), jsx(Card.Body, {
      className: 'p-0',
      children: jsx(ListGroup, {
        children: errors.map((error, i) => {
          return jsx(ListGroup.Item, {
            className: 'border-0',
            children: jsx("span", {
              children: error.stack
            })
          }, i);
        })
      })
    })]
  });
}

function IconButton(props) {
  const {
    icon,
    iconType,
    className,
    uiSchema,
    registry,
    ...otherProps
  } = props;
  return jsx(Button, {
    block: iconType === 'block',
    ...otherProps,
    variant: props.variant || 'light',
    size: 'sm',
    children: icon
  });
}
function CopyButton(props) {
  const {
    registry: {
      translateString
    }
  } = props;
  return jsx(IconButton, {
    title: translateString(TranslatableString.CopyButton),
    ...props,
    icon: jsx(IoIosCopy, {})
  });
}
function MoveDownButton(props) {
  const {
    registry: {
      translateString
    }
  } = props;
  return jsx(IconButton, {
    title: translateString(TranslatableString.MoveDownButton),
    ...props,
    icon: jsx(AiOutlineArrowDown, {})
  });
}
function MoveUpButton(props) {
  const {
    registry: {
      translateString
    }
  } = props;
  return jsx(IconButton, {
    title: translateString(TranslatableString.MoveUpButton),
    ...props,
    icon: jsx(AiOutlineArrowUp, {})
  });
}
function RemoveButton(props) {
  const {
    registry: {
      translateString
    }
  } = props;
  return jsx(IconButton, {
    title: translateString(TranslatableString.RemoveButton),
    ...props,
    variant: 'danger',
    icon: jsx(IoIosRemove, {})
  });
}

/** The `FieldErrorTemplate` component renders the errors local to the particular field
 *
 * @param props - The `FieldErrorProps` for the errors being rendered
 */
function FieldErrorTemplate(props) {
  const {
    errors = [],
    idSchema
  } = props;
  if (errors.length === 0) {
    return null;
  }
  const id = errorId(idSchema);
  return jsx(ListGroup, {
    as: 'ul',
    id: id,
    children: errors.map((error, i) => {
      return jsx(ListGroup.Item, {
        as: 'li',
        className: 'border-0 m-0 p-0',
        children: jsx("small", {
          className: 'm-0 text-danger',
          children: error
        })
      }, i);
    })
  });
}

/** The `FieldHelpTemplate` component renders any help desired for a field
 *
 * @param props - The `FieldHelpProps` to be rendered
 */
function FieldHelpTemplate(props) {
  const {
    idSchema,
    help,
    hasErrors
  } = props;
  if (!help) {
    return null;
  }
  const id = helpId(idSchema);
  return jsx(Form$1.Text, {
    className: hasErrors ? 'text-danger' : 'text-muted',
    id: id,
    children: help
  });
}

function FieldTemplate({
  id,
  children,
  displayLabel,
  rawErrors = [],
  errors,
  help,
  description,
  rawDescription,
  classNames,
  style,
  disabled,
  label,
  hidden,
  onDropPropertyClick,
  onKeyChange,
  readonly,
  required,
  schema,
  uiSchema,
  registry
}) {
  const uiOptions = getUiOptions(uiSchema);
  const WrapIfAdditionalTemplate = getTemplate('WrapIfAdditionalTemplate', registry, uiOptions);
  if (hidden) {
    return jsx("div", {
      className: 'hidden',
      children: children
    });
  }
  return jsx(WrapIfAdditionalTemplate, {
    classNames: classNames,
    style: style,
    disabled: disabled,
    id: id,
    label: label,
    onDropPropertyClick: onDropPropertyClick,
    onKeyChange: onKeyChange,
    readonly: readonly,
    required: required,
    schema: schema,
    uiSchema: uiSchema,
    registry: registry,
    children: jsxs(Form$1.Group, {
      children: [displayLabel && jsxs(Form$1.Label, {
        htmlFor: id,
        className: rawErrors.length > 0 ? 'text-danger' : '',
        children: [label, required ? '*' : null]
      }), children, displayLabel && rawDescription && jsx(Form$1.Text, {
        className: rawErrors.length > 0 ? 'text-danger' : 'text-muted',
        children: description
      }), errors, help]
    })
  });
}

function ObjectFieldTemplate({
  description,
  title,
  properties,
  required,
  uiSchema,
  idSchema,
  schema,
  formData,
  onAddClick,
  disabled,
  readonly,
  registry
}) {
  const uiOptions = getUiOptions(uiSchema);
  const TitleFieldTemplate = getTemplate('TitleFieldTemplate', registry, uiOptions);
  const DescriptionFieldTemplate = getTemplate('DescriptionFieldTemplate', registry, uiOptions);
  // Button templates are not overridden in the uiSchema
  const {
    ButtonTemplates: {
      AddButton
    }
  } = registry.templates;
  return jsxs(Fragment, {
    children: [title && jsx(TitleFieldTemplate, {
      id: titleId(idSchema),
      title: title,
      required: required,
      schema: schema,
      uiSchema: uiSchema,
      registry: registry
    }), description && jsx(DescriptionFieldTemplate, {
      id: descriptionId(idSchema),
      description: description,
      schema: schema,
      uiSchema: uiSchema,
      registry: registry
    }), jsxs(Container, {
      fluid: true,
      className: 'p-0',
      children: [properties.map((element, index) => jsx(Row, {
        style: {
          marginBottom: '10px'
        },
        className: element.hidden ? 'd-none' : undefined,
        children: jsxs(Col, {
          xs: 12,
          children: [" ", element.content]
        })
      }, index)), canExpand(schema, uiSchema, formData) ? jsx(Row, {
        children: jsx(Col, {
          xs: {
            offset: 9,
            span: 3
          },
          className: 'py-4',
          children: jsx(AddButton, {
            onClick: onAddClick(schema),
            disabled: disabled || readonly,
            className: 'object-property-expand',
            uiSchema: uiSchema,
            registry: registry
          })
        })
      }) : null]
    })]
  });
}

function SubmitButton(props) {
  const {
    submitText,
    norender,
    props: submitButtonProps
  } = getSubmitButtonOptions(props.uiSchema);
  if (norender) {
    return null;
  }
  return jsx("div", {
    children: jsx(Button, {
      variant: 'primary',
      type: 'submit',
      ...submitButtonProps,
      children: submitText
    })
  });
}

function TitleField({
  id,
  title,
  uiSchema
}) {
  const uiOptions = getUiOptions(uiSchema);
  return jsxs("div", {
    id: id,
    className: 'my-1',
    children: [jsx("h5", {
      children: uiOptions.title || title
    }), jsx("hr", {
      className: 'border-0 bg-secondary',
      style: {
        height: '1px'
      }
    })]
  });
}

function WrapIfAdditionalTemplate({
  classNames,
  style,
  children,
  disabled,
  id,
  label,
  onDropPropertyClick,
  onKeyChange,
  readonly,
  required,
  schema,
  uiSchema,
  registry
}) {
  const {
    templates,
    translateString
  } = registry;
  // Button templates are not overridden in the uiSchema
  const {
    RemoveButton
  } = templates.ButtonTemplates;
  const keyLabel = translateString(TranslatableString.KeyLabel, [label]);
  const additional = (ADDITIONAL_PROPERTY_FLAG in schema);
  if (!additional) {
    return jsx("div", {
      className: classNames,
      style: style,
      children: children
    });
  }
  const handleBlur = ({
    target
  }) => onKeyChange(target.value);
  const keyId = `${id}-key`;
  return jsxs(Row, {
    className: classNames,
    style: style,
    children: [jsx(Col, {
      xs: 5,
      children: jsxs(Form$1.Group, {
        children: [jsx(Form$1.Label, {
          htmlFor: keyId,
          children: keyLabel
        }), jsx(Form$1.Control, {
          required: required,
          defaultValue: label,
          disabled: disabled || readonly,
          id: keyId,
          name: keyId,
          onBlur: !readonly ? handleBlur : undefined,
          type: 'text'
        })]
      })
    }), jsx(Col, {
      xs: 5,
      children: children
    }), jsx(Col, {
      xs: 2,
      className: 'py-4',
      children: jsx(RemoveButton, {
        iconType: 'block',
        className: 'w-100',
        disabled: disabled || readonly,
        onClick: onDropPropertyClick(label),
        uiSchema: uiSchema,
        registry: registry
      })
    })]
  }, keyId);
}

function generateTemplates() {
  return {
    ArrayFieldItemTemplate,
    ArrayFieldTemplate,
    BaseInputTemplate,
    ButtonTemplates: {
      AddButton,
      CopyButton,
      MoveDownButton,
      MoveUpButton,
      RemoveButton,
      SubmitButton
    },
    DescriptionFieldTemplate: DescriptionField,
    ErrorListTemplate: ErrorList,
    FieldErrorTemplate,
    FieldHelpTemplate,
    FieldTemplate,
    ObjectFieldTemplate,
    TitleFieldTemplate: TitleField,
    WrapIfAdditionalTemplate
  };
}
var Templates = /*#__PURE__*/generateTemplates();

function CheckboxWidget(props) {
  const {
    id,
    value,
    disabled,
    readonly,
    label,
    hideLabel,
    schema,
    autofocus,
    options,
    onChange,
    onBlur,
    onFocus,
    registry,
    uiSchema
  } = props;
  // Because an unchecked checkbox will cause html5 validation to fail, only add
  // the "required" attribute if the field value must be "true", due to the
  // "const" or "enum" keywords
  const required = schemaRequiresTrueValue(schema);
  const DescriptionFieldTemplate = getTemplate('DescriptionFieldTemplate', registry, options);
  const _onChange = ({
    target: {
      checked
    }
  }) => onChange(checked);
  const _onBlur = ({
    target: {
      checked
    }
  }) => onBlur(id, checked);
  const _onFocus = ({
    target: {
      checked
    }
  }) => onFocus(id, checked);
  const description = options.description || schema.description;
  return jsxs(Form$1.Group, {
    className: `checkbox ${disabled || readonly ? 'disabled' : ''}`,
    "aria-describedby": ariaDescribedByIds(id),
    children: [!hideLabel && !!description && jsx(DescriptionFieldTemplate, {
      id: descriptionId(id),
      description: description,
      schema: schema,
      uiSchema: uiSchema,
      registry: registry
    }), jsx(Form$1.Check, {
      id: id,
      name: id,
      label: labelValue(label, hideLabel || !label),
      checked: typeof value === 'undefined' ? false : value,
      required: required,
      disabled: disabled || readonly,
      autoFocus: autofocus,
      onChange: _onChange,
      type: 'checkbox',
      onBlur: _onBlur,
      onFocus: _onFocus
    })]
  });
}

function CheckboxesWidget({
  id,
  disabled,
  options,
  value,
  autofocus,
  readonly,
  required,
  onChange,
  onBlur,
  onFocus
}) {
  const {
    enumOptions,
    enumDisabled,
    inline,
    emptyValue
  } = options;
  const checkboxesValues = Array.isArray(value) ? value : [value];
  const _onChange = index => ({
    target: {
      checked
    }
  }) => {
    if (checked) {
      onChange(enumOptionsSelectValue(index, checkboxesValues, enumOptions));
    } else {
      onChange(enumOptionsDeselectValue(index, checkboxesValues, enumOptions));
    }
  };
  const _onBlur = ({
    target: {
      value
    }
  }) => onBlur(id, enumOptionsValueForIndex(value, enumOptions, emptyValue));
  const _onFocus = ({
    target: {
      value
    }
  }) => onFocus(id, enumOptionsValueForIndex(value, enumOptions, emptyValue));
  return jsx(Form$1.Group, {
    children: Array.isArray(enumOptions) && enumOptions.map((option, index) => {
      const checked = enumOptionsIsSelected(option.value, checkboxesValues);
      const itemDisabled = Array.isArray(enumDisabled) && enumDisabled.indexOf(option.value) !== -1;
      return jsx(Form$1.Check, {
        inline: inline,
        custom: true,
        required: required,
        checked: checked,
        className: 'bg-transparent border-0',
        type: 'checkbox',
        id: optionId(id, index),
        name: id,
        label: option.label,
        autoFocus: autofocus && index === 0,
        onChange: _onChange(index),
        onBlur: _onBlur,
        onFocus: _onFocus,
        disabled: disabled || itemDisabled || readonly,
        "aria-describedby": ariaDescribedByIds(id)
      }, option.value);
    })
  });
}

function RadioWidget({
  id,
  options,
  value,
  required,
  disabled,
  readonly,
  onChange,
  onBlur,
  onFocus
}) {
  const {
    enumOptions,
    enumDisabled,
    emptyValue
  } = options;
  const _onChange = ({
    target: {
      value
    }
  }) => onChange(enumOptionsValueForIndex(value, enumOptions, emptyValue));
  const _onBlur = ({
    target: {
      value
    }
  }) => onBlur(id, enumOptionsValueForIndex(value, enumOptions, emptyValue));
  const _onFocus = ({
    target: {
      value
    }
  }) => onFocus(id, enumOptionsValueForIndex(value, enumOptions, emptyValue));
  const inline = Boolean(options && options.inline);
  return jsx(Form$1.Group, {
    className: 'mb-0',
    children: Array.isArray(enumOptions) && enumOptions.map((option, index) => {
      const itemDisabled = Array.isArray(enumDisabled) && enumDisabled.indexOf(option.value) !== -1;
      const checked = enumOptionsIsSelected(option.value, value);
      const radio = jsx(Form$1.Check, {
        inline: inline,
        label: option.label,
        id: optionId(id, index),
        name: id,
        type: 'radio',
        disabled: disabled || itemDisabled || readonly,
        checked: checked,
        required: required,
        value: String(index),
        onChange: _onChange,
        onBlur: _onBlur,
        onFocus: _onFocus,
        "aria-describedby": ariaDescribedByIds(id)
      }, index);
      return radio;
    })
  });
}

function RangeWidget(props) {
  const {
    value,
    label,
    hideLabel,
    options,
    registry
  } = props;
  const BaseInputTemplate = getTemplate('BaseInputTemplate', registry, options);
  return jsx(BaseInputTemplate, {
    ...props,
    extraProps: {
      label: labelValue(label || undefined, hideLabel)
    },
    children: jsx("span", {
      className: 'range-view',
      children: value
    })
  });
}

function SelectWidget({
  schema,
  id,
  options,
  required,
  disabled,
  readonly,
  value,
  multiple,
  autofocus,
  onChange,
  onBlur,
  onFocus,
  placeholder,
  rawErrors = []
}) {
  const {
    enumOptions,
    enumDisabled,
    emptyValue: optEmptyValue
  } = options;
  const emptyValue = multiple ? [] : '';
  function getValue(event, multiple) {
    if (multiple) {
      return [].slice.call(event.target.options).filter(o => o.selected).map(o => o.value);
    } else {
      return event.target.value;
    }
  }
  const selectedIndexes = enumOptionsIndexForValue(value, enumOptions, multiple);
  return jsxs(Form$1.Control, {
    as: 'select',
    bsPrefix: 'custom-select',
    id: id,
    name: id,
    value: typeof selectedIndexes === 'undefined' ? emptyValue : selectedIndexes,
    required: required,
    multiple: multiple,
    disabled: disabled || readonly,
    autoFocus: autofocus,
    className: rawErrors.length > 0 ? 'is-invalid' : '',
    onBlur: onBlur && (event => {
      const newValue = getValue(event, multiple);
      onBlur(id, enumOptionsValueForIndex(newValue, enumOptions, optEmptyValue));
    }),
    onFocus: onFocus && (event => {
      const newValue = getValue(event, multiple);
      onFocus(id, enumOptionsValueForIndex(newValue, enumOptions, optEmptyValue));
    }),
    onChange: event => {
      const newValue = getValue(event, multiple);
      onChange(enumOptionsValueForIndex(newValue, enumOptions, optEmptyValue));
    },
    "aria-describedby": ariaDescribedByIds(id),
    children: [!multiple && schema.default === undefined && jsx("option", {
      value: '',
      children: placeholder
    }), enumOptions.map(({
      value,
      label
    }, i) => {
      const disabled = Array.isArray(enumDisabled) && enumDisabled.indexOf(value) != -1;
      return jsx("option", {
        id: label,
        value: String(i),
        disabled: disabled,
        children: label
      }, i);
    })]
  });
}

function TextareaWidget({
  id,
  placeholder,
  value,
  required,
  disabled,
  autofocus,
  readonly,
  onBlur,
  onFocus,
  onChange,
  options
}) {
  const _onChange = ({
    target: {
      value
    }
  }) => onChange(value === '' ? options.emptyValue : value);
  const _onBlur = ({
    target: {
      value
    }
  }) => onBlur(id, value);
  const _onFocus = ({
    target: {
      value
    }
  }) => onFocus(id, value);
  return jsx(InputGroup, {
    children: jsx(FormControl, {
      id: id,
      name: id,
      as: 'textarea',
      placeholder: placeholder,
      disabled: disabled,
      readOnly: readonly,
      value: value,
      required: required,
      autoFocus: autofocus,
      rows: options.rows || 5,
      onChange: _onChange,
      onBlur: _onBlur,
      onFocus: _onFocus,
      "aria-describedby": ariaDescribedByIds(id)
    })
  });
}

function generateWidgets() {
  return {
    CheckboxWidget,
    CheckboxesWidget,
    RadioWidget,
    RangeWidget,
    SelectWidget,
    TextareaWidget
  };
}
var Widgets = /*#__PURE__*/generateWidgets();

function generateTheme() {
  return {
    templates: generateTemplates(),
    widgets: generateWidgets()
  };
}
var Theme = /*#__PURE__*/generateTheme();

function generateForm() {
  return withTheme(generateTheme());
}
var Form = /*#__PURE__*/generateForm();

export { Form, Templates, Theme, Widgets, Form as default, generateForm, generateTemplates, generateTheme, generateWidgets };
//# sourceMappingURL=bootstrap-4.esm.js.map
